import { NestedTreeControl } from '@angular/cdk/tree';
import 'rxjs';
import { MonacoEditorModule } from 'ngx-monaco-editor';
import { MatTabsModule } from '@angular/material/tabs';
import { MatTreeNestedDataSource, MatTreeModule } from '@angular/material/tree';
import { MatButtonModule } from '@angular/material/button';
import { MatMenuModule } from '@angular/material/menu';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatRippleModule } from '@angular/material/core';
import { FormControl, FormsModule } from '@angular/forms';
import { Injectable, Component, ViewChild, Input, Output, EventEmitter, NgModule } from '@angular/core';
import { MatTableModule } from '@angular/material/table';
import { MatCardModule } from '@angular/material/card';
import { CommonModule } from '@angular/common';
import { MatIconModule } from '@angular/material/icon';
import { HttpClientModule } from '@angular/common/http';
import { MatMenuTrigger, MatDividerModule } from '@angular/material';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class NgxQueryEditorAbstractService {
    constructor() {
        this.queryExecuted = true;
    }
}
NgxQueryEditorAbstractService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const Actions = {
    // Damn love the symmetry in this
    Execute: 'execute',
    Delete: 'delete',
    Clear: 'clear',
    Undo: 'undo',
    Redo: 'redo',
    Theme: 'theme',
    Feedback: 'feedbck',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class QueryAreaComponent {
    constructor() {
        this.editorOptions = { theme: 'vs-light', language: 'sql' };
        this.tabs = [];
        this.tabNames = [];
        this.selected = new FormControl(0);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} dbName
     * @return {?}
     */
    addTab(dbName) {
        // This is just a workaround to delay the function call if monaco editor is not loaded
        // TODO: change this to a clean implementation http://192.168.0.78/ikhalsi/ng-db-query-editor/issues/32
        try {
            this.addTabToMonacoEditor(dbName);
        }
        catch (error) {
            setTimeout((/**
             * @return {?}
             */
            () => this.addTabToMonacoEditor(dbName)), 1000);
        }
    }
    /**
     * @param {?} state
     * @return {?}
     */
    setEmptyState(state) {
        this.emptyState = state;
    }
    /**
     * @private
     * @param {?} dbName
     * @return {?}
     */
    addTabToMonacoEditor(dbName) {
        /** @type {?} */
        const model = monaco.editor.createModel(' -- Using ' + dbName + '\n', 'sql');
        this.editor._editor.setModel(model);
        this.tabs.push({
            tabDatabase: dbName,
            tabEditorModel: model,
            tabModelUri: model.uri
        });
        this.selected.setValue(this.tabs.length - 1);
        this.tabNames.push('new query-' + dbName);
        this.selectedDbName = dbName;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onChangeTab(event) {
        this.changeTab(event.index);
    }
    /**
     * @param {?} index
     * @return {?}
     */
    onCloseTab(index) {
        this.changeTab(index + 1);
        this.tabNames.splice(index, 1);
        this.tabs.splice(index, 1);
    }
    /**
     * @private
     * @param {?} index
     * @return {?}
     */
    changeTab(index) {
        if (index === this.tabs.length) {
            this.editor._editor.setModel(this.tabs[index - 1].tabEditorModel);
            this.selectedDbName = this.tabs[index - 1].tabDatabase;
            this.code = monaco.editor.getModel(this.tabs[index - 1].tabModelUri).getValue();
        }
        else {
            this.editor._editor.setModel(this.tabs[index].tabEditorModel);
            this.selectedDbName = this.tabs[index].tabDatabase;
            this.code = monaco.editor.getModel(this.tabs[index].tabModelUri).getValue();
        }
    }
    /**
     * @return {?}
     */
    getCode() {
        return this.code;
    }
}
QueryAreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-query-area',
                template: "<mat-tab-group [disableRipple]=\"true\" [selectedIndex]=\"selected.value\" (selectedIndexChange)=\"selected.setValue($event)\" (selectedTabChange)=\"onChangeTab($event)\">\r\n  <mat-tab *ngFor=\"let tab of tabNames; let index = index\" [label]=\"tab\">\r\n      <ng-template mat-tab-label>\r\n          {{tab}}\r\n          <button *ngIf=\"tabNames.length !== 1\" mat-icon-button aria-label=\"Close tab\" (click)=\"onCloseTab(index)\" >\r\n              <mat-icon>close</mat-icon>\r\n          </button>\r\n      </ng-template> \r\n    </mat-tab>\r\n</mat-tab-group>\r\n<mat-divider></mat-divider>\r\n<mat-card\r\n  class=\"mat-elevation-z0 empty-state-container\" *ngIf=\"emptyState; else noEmptyState\" >\r\n  <mat-icon class=\"emptyStateIcon\" color=\"accent\"> photo_filter </mat-icon>\r\n  <h2 class=\"mat-h2 mat-title\">Server has no database</h2>\r\n  <mat-card-subtitle>Please create databases other than Master DB</mat-card-subtitle>\r\n</mat-card>\r\n\r\n<ng-template #noEmptyState>\r\n  <ngx-monaco-editor #editor [options]=\"editorOptions\" [(ngModel)]=\"code\" class=\"editor\"></ngx-monaco-editor>\r\n</ng-template>\r\n",
                styles: [":host{display:-webkit-flex;display:flex;-webkit-flex-flow:column nowrap;flex-flow:column nowrap}:host mat-tab-group{height:32px}:host .editor{-webkit-flex:1 1 auto;flex:1 1 auto}:host .editor /deep/ .editor-container{height:100%}:host /deep/ .mat-tab-label{height:32px}:host .empty-state-container{padding-top:16px;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;-webkit-justify-content:center;justify-content:center;-webkit-align-items:center;align-items:center;height:90%}:host .emptyStateIcon{font-size:100px;height:100px;width:100px;line-height:100px}"]
            }] }
];
QueryAreaComponent.propDecorators = {
    editor: [{ type: ViewChild, args: ['editor',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DbExplorerComponent {
    /**
     * @param {?} queryEditorService
     */
    constructor(queryEditorService) {
        this.queryEditorService = queryEditorService;
        this.treeControl = new NestedTreeControl((/**
         * @param {?} node
         * @return {?}
         */
        node => node.children));
        this.dataSource = new MatTreeNestedDataSource();
        this.contextMenuPosition = { x: '0px', y: '0px' };
        this.newQueryTab = new EventEmitter();
        this.stateEmitter = new EventEmitter();
        this.serverTree = [];
        this.hasChild = (/**
         * @param {?} _
         * @param {?} node
         * @return {?}
         */
        (_, node) => node.children && (node.type === 'server' || node.type === 'database' || node.type === 'table' || node.type === 'folder'));
    }
    /**
     * @param {?} event
     * @param {?} item
     * @return {?}
     */
    onContextMenu(event, item) {
        event.preventDefault();
        this.contextMenuPosition.x = event.clientX + 'px';
        this.contextMenuPosition.y = event.clientY + 'px';
        this.contextMenu.menuData = { 'node': item };
        this.contextMenu.openMenu();
    }
    /**
     * @param {?} $event
     * @param {?} nodeName
     * @return {?}
     */
    onOpenInEditor($event, nodeName) {
        this.newQueryTab.emit(nodeName);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.serverModel$.subscribe((/**
         * @param {?} server
         * @return {?}
         */
        server => {
            this.serverName = server.name;
            this.serverTree = [
                {
                    name: this.serverName,
                    type: 'server',
                    children: []
                }
            ];
        }));
        this.serverSchema$.subscribe((/**
         * @param {?} result
         * @return {?}
         */
        result => {
            result.forEach((/**
             * @param {?} elt
             * @return {?}
             */
            elt => {
                /** @type {?} */
                const dbNode = {
                    name: elt.database_name,
                    type: 'database',
                    children: [
                        {
                            name: 'tables',
                            type: 'folder',
                            children: []
                        }
                    ]
                };
                this.serverTree[0].children.push(dbNode);
            }));
            this.emptyState = this.checkEmptyState();
            this.stateEmitter.emit(this.emptyState);
            if (this.emptyState === false) {
                this.newQueryTab.emit(this.serverTree[0].children[1].name);
            }
            this.dataSource.data = this.serverTree;
        }));
    }
    /**
     * @param {?} node
     * @return {?}
     */
    onClick(node) {
        if (!this.treeControl.isExpanded(node)) {
            if (node.name === 'tables' && node.type === 'folder') {
                /** @type {?} */
                const dbNode = this.serverTree[0].children.filter((/**
                 * @param {?} child
                 * @return {?}
                 */
                child => child.children.includes(node)))[0];
                /** @type {?} */
                const dbIndex = this.serverTree[0].children.indexOf(this.serverTree[0].children.filter((/**
                 * @param {?} child
                 * @return {?}
                 */
                child => child === dbNode))[0]);
                /** @type {?} */
                const nodeIndex = this.serverTree[0].children[dbIndex].children.indexOf(node);
                this.serverTree[0].children[dbIndex].children[nodeIndex].children = [];
                this.queryEditorService.getCollectionSchema(node.name, dbNode.name).subscribe((/**
                 * @param {?} result
                 * @return {?}
                 */
                result => {
                    result.forEach((/**
                     * @param {?} elt
                     * @return {?}
                     */
                    elt => {
                        /** @type {?} */
                        const dbNodetoAdd = {
                            name: elt.tablE_SCHEMA + '.' + elt.tablE_NAME,
                            type: 'table',
                            children: [
                                {
                                    name: 'columns',
                                    type: 'folder',
                                    children: []
                                }
                            ]
                        };
                        this.serverTree[0].children[dbIndex].children[nodeIndex].children.push(dbNodetoAdd);
                    }));
                    this.dataSource.data = null;
                    this.dataSource.data = this.serverTree;
                }));
            }
            if (node.type === 'table') {
                /** @type {?} */
                const dbName = this.serverTree[0].children.filter((/**
                 * @param {?} child
                 * @return {?}
                 */
                child => child.children[0].children.includes(node)))[0].name;
                /** @type {?} */
                const dbIndex = this.serverTree[0].children.indexOf(this.serverTree[0].children.filter((/**
                 * @param {?} child
                 * @return {?}
                 */
                child => child.name === dbName))[0]);
                /** @type {?} */
                const nodeIndex = this.serverTree[0].children[dbIndex].children[0].children.indexOf(node);
                /** @type {?} */
                const tableName = this.serverTree[0].children[dbIndex].children[0].children[nodeIndex].name;
                this.serverTree[0].children[dbIndex].children[0].children[nodeIndex].children = [];
                this.queryEditorService.getCollectionSchema('columns', dbName).subscribe((/**
                 * @param {?} result
                 * @return {?}
                 */
                result => {
                    result.forEach((/**
                     * @param {?} elt
                     * @return {?}
                     */
                    elt => {
                        if (elt.tablE_SCHEMA + '.' + elt.tablE_NAME === tableName) {
                            /** @type {?} */
                            const dbNodetoAdd = {
                                name: elt.columN_NAME,
                                type: 'column',
                            };
                            this.serverTree[0].children[dbIndex].children[0].children[nodeIndex].children.push(dbNodetoAdd);
                        }
                    }));
                    this.dataSource.data = null;
                    this.dataSource.data = this.serverTree;
                }));
            }
        }
    }
    /**
     * @return {?}
     */
    onRefreshClick() {
        this.serverTree = [
            {
                name: this.serverName,
                type: 'server',
                children: []
            }
        ];
        this.serverSchema$.subscribe((/**
         * @param {?} result
         * @return {?}
         */
        result => {
            result.forEach((/**
             * @param {?} elt
             * @return {?}
             */
            elt => {
                /** @type {?} */
                const dbNode = {
                    name: elt.database_name,
                    type: 'database',
                    children: [
                        {
                            name: 'tables',
                            type: 'folder',
                            children: []
                        }
                    ]
                };
                this.serverTree[0].children.push(dbNode);
            }));
            this.emptyState = this.checkEmptyState();
            this.stateEmitter.emit(this.emptyState);
            this.dataSource.data = this.serverTree;
        }));
    }
    /**
     * @return {?}
     */
    checkEmptyState() {
        return (this.serverTree[0].children.length === 0 ||
            (this.serverTree[0].children[0].name === 'master' && this.serverTree[0].children.length === 1));
    }
    /**
     * @param {?} node
     * @return {?}
     */
    ResolveIcon(node) {
        if (node.type === 'folder') {
            return 'folder';
        }
        else if (node.type === 'view') {
            return 'pageview';
        }
        else if (node.type === 'table') {
            return 'table_chart';
        }
        else if (node.type === 'column') {
            return 'view_column';
        }
        else if (node.type === 'index') {
            return 'view_headline';
        }
        else if (node.type === 'trigger') {
            return 'dehaze';
        }
        else if (node.type === 'server') {
            return 'dvr';
        }
        else if (node.type === 'database') {
            return 'apps';
        }
        else {
            return 'insert_drive_file';
        }
    }
}
DbExplorerComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-db-explorer',
                template: "<mat-card>\r\n  <mat-card-header>\r\n    <mat-card-title>Server Explorer</mat-card-title>\r\n    <button mat-icon-button (click)=\"onRefreshClick()\" [disableRipple]=\"true\" >\r\n      <mat-icon [color]=\"'accent'\" class=\"refresh-button\" >refresh</mat-icon>\r\n    </button>\r\n  </mat-card-header>\r\n  <mat-tree [dataSource]=\"dataSource\" [treeControl]=\"treeControl\" class=\"db-tree\">\r\n    <!-- This is the tree node template for leaf nodes -->\r\n    <mat-tree-node *matTreeNodeDef=\"let node\" matTreeNodeToggle>\r\n      <li class=\"mat-tree-node\">\r\n        <!-- use a disabled button to provide padding for tree leaf -->\r\n        <button mat-icon-button disabled></button>\r\n        <mat-icon class=\"mat-icon-rtl-mirror\" color=\"accent\">\r\n          {{ResolveIcon(node)}}\r\n        </mat-icon>\r\n\r\n        <div class=\"node-text\" matTooltip=\"{{node.name}}\">\r\n          {{node.name}}\r\n        </div>\r\n      </li>\r\n    </mat-tree-node>\r\n    <!-- This is the tree node template for expandable nodes -->\r\n    <mat-nested-tree-node *matTreeNodeDef=\"let node; when: hasChild\">\r\n      <li>\r\n        <div class=\"mat-tree-node\">\r\n          <button mat-icon-button matTreeNodeToggle [attr.aria-label]=\"'toggle ' + node.name\">\r\n            <mat-icon class=\"mat-icon-rtl-mirror\" (click)=\"onClick(node)\">\r\n              {{treeControl.isExpanded(node) ? 'expand_more' : 'chevron_right'}}\r\n            </mat-icon>\r\n          </button>\r\n          <mat-icon class=\"mat-icon-rtl-mirror\" color=\"accent\">\r\n            {{ResolveIcon(node)}}\r\n          </mat-icon>\r\n\r\n          <div class=\"node\" *ngIf=\"node.type ==='database'; else notDatabase\" (contextmenu)=\"onContextMenu($event, node)\"> \r\n            {{node.name}}\r\n            <div style=\"visibility: hidden; position: fixed\"\r\n                [style.left]=\"contextMenuPosition.x\"\r\n                [style.top]=\"contextMenuPosition.y\"\r\n                [matMenuTriggerFor]=\"contextMenu\">\r\n            </div>\r\n            <mat-menu [class]=\"'custom-menu-content'\" #contextMenu=\"matMenu\" >\r\n              <ng-template matMenuContent let-node=\"node\">\r\n                <button [disabled]=\"node.name === 'master'\" mat-menu-item (click)=\"onOpenInEditor($event, node.name)\">Open in editor</button>\r\n              </ng-template>\r\n            </mat-menu>\r\n          </div>\r\n          <ng-template #notDatabase>\r\n            <div class=\"node-text\" matTooltip=\"{{node.name}}\">\r\n              {{node.name}} \r\n            </div>\r\n          </ng-template>\r\n\r\n        </div>\r\n        <ul [class.db-tree-invisible]=\"!treeControl.isExpanded(node)\">\r\n          <ng-container matTreeNodeOutlet></ng-container>\r\n        </ul>\r\n      </li>\r\n    </mat-nested-tree-node>\r\n  </mat-tree>\r\n</mat-card>\r\n",
                styles: [":host{display:-webkit-flex;display:flex;-webkit-flex-flow:column nowrap;flex-flow:column nowrap}:host ul{padding-left:8px}:host .mat-tree-node{min-height:0!important}:host .mat-tree-node .node-text{-webkit-flex:0 1 auto;flex:0 1 auto;text-overflow:ellipsis;overflow:hidden;white-space:nowrap}:host mat-card{-webkit-flex:1 1 auto;flex:1 1 auto;border-radius:0;padding:8px 8px 0 0}:host mat-card-header{display:-webkit-flex;display:flex;-webkit-align-items:baseline;align-items:baseline;-webkit-justify-content:space-between;justify-content:space-between}:host mat-card-header button:focus mat-icon{-webkit-animation:1s ease-in-out rotate;animation:1s ease-in-out rotate}@-webkit-keyframes rotate{from{-webkit-transform:rotate(0);transform:rotate(0)}to{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes rotate{from{-webkit-transform:rotate(0);transform:rotate(0)}to{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}:host .db-tree{padding-left:16px}:host .db-tree-invisible{display:none}:host .db-tree li,:host .db-tree ul{margin-top:0;margin-bottom:0;list-style-type:none}:host mat-icon{margin-right:8px}.node{cursor:pointer}"]
            }] }
];
/** @nocollapse */
DbExplorerComponent.ctorParameters = () => [
    { type: NgxQueryEditorAbstractService }
];
DbExplorerComponent.propDecorators = {
    contextMenu: [{ type: ViewChild, args: [MatMenuTrigger,] }],
    newQueryTab: [{ type: Output }],
    stateEmitter: [{ type: Output }],
    serverSchema$: [{ type: Input }],
    serverModel$: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxQueryEditorComponent {
    /**
     * @param {?} queryEditorService
     */
    constructor(queryEditorService) {
        this.queryEditorService = queryEditorService;
        this.result = [];
        this.query = {
            database: '',
            queryBody: ''
        };
        this.queryResult = {
            result: [],
            schema: []
        };
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.serverModel$ = this.queryEditorService.getSqlServerById(this.sqlServerId);
        this.serverSchema$ = this.queryEditorService.getCollectionSchema('databases', null);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    handleAction($event) {
        if ($event === Actions.Execute) {
            this.execute();
        }
    }
    /**
     * @param {?} dbName
     * @return {?}
     */
    onNewQueryTab(dbName) {
        this.queryArea.addTab(dbName);
    }
    /**
     * @param {?} state
     * @return {?}
     */
    onStateEmitter(state) {
        this.queryArea.setEmptyState(state);
    }
    /**
     * @return {?}
     */
    execute() {
        /** @type {?} */
        const code = this.queryArea.getCode();
        this.query.database = this.queryArea.selectedDbName;
        this.query.queryBody = code;
        if (code) {
            this.queryEditorService.executeQuery(this.query).subscribe((/**
             * @param {?} result
             * @return {?}
             */
            result => this.queryResult = result));
        }
        else {
            alert('No code to execute ');
        }
    }
}
NgxQueryEditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-ngx-query-editor',
                template: "    <lib-db-explorer #dbexplorer [serverSchema$]=\"serverSchema$\" [serverModel$]=\"serverModel$\"\r\n      (newQueryTab)=\"onNewQueryTab($event)\" (stateEmitter)=\"onStateEmitter($event)\"></lib-db-explorer>\r\n    <mat-divider [vertical]=\"true\"></mat-divider>\r\n    <div class=\"content\">\r\n      <lib-toolbar (actionEmitter)=\"handleAction($event)\"></lib-toolbar>\r\n      <mat-divider></mat-divider>\r\n      <lib-query-area #queryarea></lib-query-area>\r\n      <mat-divider></mat-divider>\r\n      <lib-result-viewer [result]=\"queryResult\"></lib-result-viewer>\r\n    </div>\r\n",
                styles: [":host{display:-webkit-flex;display:flex;-webkit-flex-flow:row nowrap;flex-flow:row nowrap;-webkit-justify-content:stretch;justify-content:stretch;overflow:auto}:host lib-db-explorer{width:300px;-webkit-flex-shrink:0;flex-shrink:0;overflow:auto}:host .content{-webkit-flex:1 1 auto;flex:1 1 auto;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;overflow:auto}:host .content mat-divider{z-index:1}:host .content lib-result-viewer{-webkit-flex:0 0 225px;flex:0 0 225px}:host .content lib-query-area{-webkit-flex:1 1 auto;flex:1 1 auto}"]
            }] }
];
/** @nocollapse */
NgxQueryEditorComponent.ctorParameters = () => [
    { type: NgxQueryEditorAbstractService }
];
NgxQueryEditorComponent.propDecorators = {
    sqlServerId: [{ type: Input }],
    queryArea: [{ type: ViewChild, args: ['queryarea',] }],
    dbExplorer: [{ type: ViewChild, args: ['dbexplorer',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class QueryAreaModule {
}
QueryAreaModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    QueryAreaComponent
                ],
                imports: [
                    CommonModule,
                    FormsModule,
                    MatTabsModule,
                    MatIconModule,
                    MatButtonModule,
                    MatDividerModule,
                    MatCardModule,
                    MonacoEditorModule.forRoot()
                ],
                providers: [],
                exports: [QueryAreaComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToolbarComponent {
    /**
     * @param {?} queraArea
     */
    constructor(queraArea) {
        this.queraArea = queraArea;
        this.actionEmitter = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} query
     * @return {?}
     */
    onExecuteQuery(query) {
        this.actionEmitter.emit(Actions.Execute);
    }
}
ToolbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-toolbar',
                template: "<button mat-flat-button matTooltip=\"execute\" color=\"primary\" (click)=\"onExecuteQuery($event)\">\r\n    <mat-icon color=\"accent\">play_arrow</mat-icon>\r\n    <span class=\"button-label\"> Run </span>\r\n</button>\r\n",
                styles: [":host{height:40px;background-color:#f2f2f2;-webkit-flex:0 1 auto;flex:0 1 auto;display:-webkit-flex;display:flex;-webkit-flex-flow:row nowrap;flex-flow:row nowrap;-webkit-justify-content:space-between;justify-content:space-between;-webkit-align-items:center;align-items:center;padding-left:4px}:host button{line-height:32px}:host .button-label{margin-right:4px}"]
            }] }
];
/** @nocollapse */
ToolbarComponent.ctorParameters = () => [
    { type: QueryAreaComponent }
];
ToolbarComponent.propDecorators = {
    actionEmitter: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToolbarModule {
}
ToolbarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ToolbarComponent
                ],
                imports: [
                    CommonModule,
                    FormsModule,
                    MatButtonModule,
                    MatIconModule
                ],
                providers: [QueryAreaComponent],
                exports: [ToolbarComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DbExplorerModule {
}
DbExplorerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    DbExplorerComponent
                ],
                imports: [
                    CommonModule,
                    FormsModule,
                    MatTreeModule,
                    MatIconModule,
                    MatButtonModule,
                    MatCardModule,
                    MatMenuModule,
                    MatTooltipModule,
                    MatRippleModule
                ],
                providers: [],
                exports: [DbExplorerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ResultViewerComponent {
    constructor() {
        this.displayedColumns = [];
    }
    /**
     * @return {?}
     */
    get result() {
        return this._result;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set result(value) {
        this._result = value;
        this.displayedData = this.result.result;
        this.displayedColumns = this.result.schema;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
ResultViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-result-viewer',
                template: "<mat-card>\r\n    <table mat-table [dataSource]=\"displayedData\">\r\n        <ng-container *ngFor=\"let col of displayedColumns\" [matColumnDef]=\"col\">\r\n            <th mat-header-cell *matHeaderCellDef mat-sort-header> {{ col }} </th>\r\n            <td mat-cell *matCellDef=\"let element\"> {{ element[col] }} </td>\r\n        </ng-container>\r\n        <tr mat-header-row *matHeaderRowDef=\"displayedColumns; sticky: true\"></tr>\r\n        <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\r\n    </table>\r\n</mat-card>",
                styles: [":host{display:-webkit-flex;display:flex;-webkit-flex-flow:column nowrap;flex-flow:column nowrap;overflow:auto}:host mat-card{-webkit-flex:1 1 auto;flex:1 1 auto;border-radius:0}:host table{width:100%}:host tr.mat-footer-row,:host tr.mat-row{height:32px}:host tr.mat-header-row{height:48px;font-style:italic}:host th.mat-header-cell{font-weight:700}"]
            }] }
];
ResultViewerComponent.propDecorators = {
    result: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ResultViewerModule {
}
ResultViewerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ResultViewerComponent
                ],
                imports: [
                    FormsModule,
                    MatTableModule,
                    CommonModule,
                    MatCardModule
                ],
                providers: [],
                exports: [ResultViewerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxQueryEditorModule {
}
NgxQueryEditorModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxQueryEditorComponent],
                imports: [
                    QueryAreaModule,
                    ToolbarModule,
                    DbExplorerModule,
                    ResultViewerModule,
                    CommonModule,
                    MatIconModule,
                    MatDividerModule,
                    HttpClientModule
                ],
                providers: [],
                exports: [NgxQueryEditorComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxQueryEditorAbstractService, NgxQueryEditorComponent, NgxQueryEditorModule, DbExplorerComponent as ɵf, DbExplorerModule as ɵe, QueryAreaComponent as ɵb, QueryAreaModule as ɵa, ResultViewerComponent as ɵh, ResultViewerModule as ɵg, ToolbarComponent as ɵd, ToolbarModule as ɵc };

//# sourceMappingURL=ngx-query-editor.js.map